@@ -222,6 +222,13 @@ class ProvisioningAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import apigee_registry_v1
 
             async def sample_create_instance():
@@ -353,6 +360,13 @@ class ProvisioningAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import apigee_registry_v1
 
             async def sample_delete_instance():
@@ -405,9 +419,6 @@ class ProvisioningAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -472,6 +483,13 @@ class ProvisioningAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import apigee_registry_v1
 
             async def sample_get_instance():
@@ -807,9 +825,11 @@ class ProvisioningAsyncClient:
                 optionally specify a ``condition``, which is a logic
                 expression that further constrains the role binding
                 based on attributes about the request and/or target
-                resource. JSON Example.
+                resource.
 
-                .. code-block:: python
+                **JSON Example**
+
+                ::
 
                     {
                       "bindings": [
@@ -926,9 +946,11 @@ class ProvisioningAsyncClient:
                 optionally specify a ``condition``, which is a logic
                 expression that further constrains the role binding
                 based on attributes about the request and/or target
-                resource. JSON Example.
+                resource.
 
-                .. code-block:: python
+                **JSON Example**
+
+                ::
 
                     {
                       "bindings": [
