@@ -248,7 +248,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the list apis method over gRPC.
 
-        ListApis returns matching APIs.
+        Returns matching APIs.
 
         Returns:
             Callable[[~.ListApisRequest],
@@ -274,7 +274,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ) -> Callable[[registry_service.GetApiRequest], Awaitable[registry_models.Api]]:
         r"""Return a callable for the get api method over gRPC.
 
-        GetApi returns a specified API.
+        Returns a specified API.
 
         Returns:
             Callable[[~.GetApiRequest],
@@ -300,7 +300,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ) -> Callable[[registry_service.CreateApiRequest], Awaitable[registry_models.Api]]:
         r"""Return a callable for the create api method over gRPC.
 
-        CreateApi creates a specified API.
+        Creates a specified API.
 
         Returns:
             Callable[[~.CreateApiRequest],
@@ -326,7 +326,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ) -> Callable[[registry_service.UpdateApiRequest], Awaitable[registry_models.Api]]:
         r"""Return a callable for the update api method over gRPC.
 
-        UpdateApi can be used to modify a specified API.
+        Used to modify a specified API.
 
         Returns:
             Callable[[~.UpdateApiRequest],
@@ -352,8 +352,8 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ) -> Callable[[registry_service.DeleteApiRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the delete api method over gRPC.
 
-        DeleteApi removes a specified API and all of the
-        resources that it owns.
+        Removes a specified API and all of the resources that
+        it owns.
 
         Returns:
             Callable[[~.DeleteApiRequest],
@@ -382,7 +382,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the list api versions method over gRPC.
 
-        ListApiVersions returns matching versions.
+        Returns matching versions.
 
         Returns:
             Callable[[~.ListApiVersionsRequest],
@@ -410,7 +410,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the get api version method over gRPC.
 
-        GetApiVersion returns a specified version.
+        Returns a specified version.
 
         Returns:
             Callable[[~.GetApiVersionRequest],
@@ -439,7 +439,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the create api version method over gRPC.
 
-        CreateApiVersion creates a specified version.
+        Creates a specified version.
 
         Returns:
             Callable[[~.CreateApiVersionRequest],
@@ -468,8 +468,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the update api version method over gRPC.
 
-        UpdateApiVersion can be used to modify a specified
-        version.
+        Used to modify a specified version.
 
         Returns:
             Callable[[~.UpdateApiVersionRequest],
@@ -497,8 +496,8 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the delete api version method over gRPC.
 
-        DeleteApiVersion removes a specified version and all
-        of the resources that it owns.
+        Removes a specified version and all of the resources
+        that it owns.
 
         Returns:
             Callable[[~.DeleteApiVersionRequest],
@@ -527,7 +526,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the list api specs method over gRPC.
 
-        ListApiSpecs returns matching specs.
+        Returns matching specs.
 
         Returns:
             Callable[[~.ListApiSpecsRequest],
@@ -555,7 +554,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the get api spec method over gRPC.
 
-        GetApiSpec returns a specified spec.
+        Returns a specified spec.
 
         Returns:
             Callable[[~.GetApiSpecRequest],
@@ -583,10 +582,10 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the get api spec contents method over gRPC.
 
-        GetApiSpecContents returns the contents of a specified spec. If
-        specs are stored with GZip compression, the default behavior is
-        to return the spec uncompressed (the mime_type response field
-        indicates the exact format returned).
+        Returns the contents of a specified spec. If specs are stored
+        with GZip compression, the default behavior is to return the
+        spec uncompressed (the mime_type response field indicates the
+        exact format returned).
 
         Returns:
             Callable[[~.GetApiSpecContentsRequest],
@@ -614,7 +613,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the create api spec method over gRPC.
 
-        CreateApiSpec creates a specified spec.
+        Creates a specified spec.
 
         Returns:
             Callable[[~.CreateApiSpecRequest],
@@ -642,7 +641,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the update api spec method over gRPC.
 
-        UpdateApiSpec can be used to modify a specified spec.
+        Used to modify a specified spec.
 
         Returns:
             Callable[[~.UpdateApiSpecRequest],
@@ -668,8 +667,8 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ) -> Callable[[registry_service.DeleteApiSpecRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the delete api spec method over gRPC.
 
-        DeleteApiSpec removes a specified spec, all
-        revisions, and all child resources (e.g. artifacts).
+        Removes a specified spec, all revisions, and all
+        child resources (e.g., artifacts).
 
         Returns:
             Callable[[~.DeleteApiSpecRequest],
@@ -697,8 +696,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the tag api spec revision method over gRPC.
 
-        TagApiSpecRevision adds a tag to a specified revision
-        of a spec.
+        Adds a tag to a specified revision of a spec.
 
         Returns:
             Callable[[~.TagApiSpecRevisionRequest],
@@ -727,7 +725,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the list api spec revisions method over gRPC.
 
-        ListApiSpecRevisions lists all revisions of a spec.
+        Lists all revisions of a spec.
         Revisions are returned in descending order of revision
         creation time.
 
@@ -757,9 +755,9 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the rollback api spec method over gRPC.
 
-        RollbackApiSpec sets the current revision to a
-        specified prior revision. Note that this creates a new
-        revision with a new revision ID.
+        Sets the current revision to a specified prior
+        revision. Note that this creates a new revision with a
+        new revision ID.
 
         Returns:
             Callable[[~.RollbackApiSpecRequest],
@@ -788,7 +786,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the delete api spec revision method over gRPC.
 
-        DeleteApiSpecRevision deletes a revision of a spec.
+        Deletes a revision of a spec.
 
         Returns:
             Callable[[~.DeleteApiSpecRevisionRequest],
@@ -817,7 +815,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the list api deployments method over gRPC.
 
-        ListApiDeployments returns matching deployments.
+        Returns matching deployments.
 
         Returns:
             Callable[[~.ListApiDeploymentsRequest],
@@ -846,7 +844,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the get api deployment method over gRPC.
 
-        GetApiDeployment returns a specified deployment.
+        Returns a specified deployment.
 
         Returns:
             Callable[[~.GetApiDeploymentRequest],
@@ -875,7 +873,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the create api deployment method over gRPC.
 
-        CreateApiDeployment creates a specified deployment.
+        Creates a specified deployment.
 
         Returns:
             Callable[[~.CreateApiDeploymentRequest],
@@ -904,8 +902,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the update api deployment method over gRPC.
 
-        UpdateApiDeployment can be used to modify a specified
-        deployment.
+        Used to modify a specified deployment.
 
         Returns:
             Callable[[~.UpdateApiDeploymentRequest],
@@ -933,8 +930,8 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the delete api deployment method over gRPC.
 
-        DeleteApiDeployment removes a specified deployment,
-        all revisions, and all child resources (e.g. artifacts).
+        Removes a specified deployment, all revisions, and
+        all child resources (e.g., artifacts).
 
         Returns:
             Callable[[~.DeleteApiDeploymentRequest],
@@ -963,8 +960,8 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the tag api deployment revision method over gRPC.
 
-        TagApiDeploymentRevision adds a tag to a specified
-        revision of a deployment.
+        Adds a tag to a specified revision of a
+        deployment.
 
         Returns:
             Callable[[~.TagApiDeploymentRevisionRequest],
@@ -993,9 +990,9 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the list api deployment revisions method over gRPC.
 
-        ListApiDeploymentRevisions lists all revisions of a
-        deployment. Revisions are returned in descending order
-        of revision creation time.
+        Lists all revisions of a deployment.
+        Revisions are returned in descending order of revision
+        creation time.
 
         Returns:
             Callable[[~.ListApiDeploymentRevisionsRequest],
@@ -1026,9 +1023,9 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the rollback api deployment method over gRPC.
 
-        RollbackApiDeployment sets the current revision to a
-        specified prior revision. Note that this creates a new
-        revision with a new revision ID.
+        Sets the current revision to a specified prior
+        revision. Note that this creates a new revision with a
+        new revision ID.
 
         Returns:
             Callable[[~.RollbackApiDeploymentRequest],
@@ -1057,8 +1054,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the delete api deployment revision method over gRPC.
 
-        DeleteApiDeploymentRevision deletes a revision of a
-        deployment.
+        Deletes a revision of a deployment.
 
         Returns:
             Callable[[~.DeleteApiDeploymentRevisionRequest],
@@ -1089,7 +1085,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the list artifacts method over gRPC.
 
-        ListArtifacts returns matching artifacts.
+        Returns matching artifacts.
 
         Returns:
             Callable[[~.ListArtifactsRequest],
@@ -1117,7 +1113,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the get artifact method over gRPC.
 
-        GetArtifact returns a specified artifact.
+        Returns a specified artifact.
 
         Returns:
             Callable[[~.GetArtifactRequest],
@@ -1145,10 +1141,10 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the get artifact contents method over gRPC.
 
-        GetArtifactContents returns the contents of a specified
-        artifact. If artifacts are stored with GZip compression, the
-        default behavior is to return the artifact uncompressed (the
-        mime_type response field indicates the exact format returned).
+        Returns the contents of a specified artifact. If artifacts are
+        stored with GZip compression, the default behavior is to return
+        the artifact uncompressed (the mime_type response field
+        indicates the exact format returned).
 
         Returns:
             Callable[[~.GetArtifactContentsRequest],
@@ -1176,7 +1172,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the create artifact method over gRPC.
 
-        CreateArtifact creates a specified artifact.
+        Creates a specified artifact.
 
         Returns:
             Callable[[~.CreateArtifactRequest],
@@ -1204,8 +1200,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ]:
         r"""Return a callable for the replace artifact method over gRPC.
 
-        ReplaceArtifact can be used to replace a specified
-        artifact.
+        Used to replace a specified artifact.
 
         Returns:
             Callable[[~.ReplaceArtifactRequest],
@@ -1231,7 +1226,7 @@ class RegistryGrpcAsyncIOTransport(RegistryTransport):
     ) -> Callable[[registry_service.DeleteArtifactRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the delete artifact method over gRPC.
 
-        DeleteArtifact removes a specified artifact.
+        Removes a specified artifact.
 
         Returns:
             Callable[[~.DeleteArtifactRequest],
